-- |
-- Module: Data.Char.AsciiFlatten
-- 
-- Function for converting European unicode UTF-8 characters to US-ASCII 
-- equivalents.
-- 
-- @
-- ghci> map asciiFlatten "café"
-- cafe
-- ghci> map asciiFlatten "Übermensch"
-- Ubermensch
-- @
--
-- The package also installs a simple command line executable 'ascii-flatten' that 
-- converts UTF-8 strings given to STDIN.


module Data.Char.AsciiFlatten (
  asciiFlatten
) where

-- | Flatten characters to nearest US-ASCII equivalent
asciiFlatten :: Char -> Char
asciiFlatten 'À' = 'A'
asciiFlatten 'Á' = 'A'
asciiFlatten 'Â' = 'A'
asciiFlatten 'Ã' = 'A'
asciiFlatten 'Ä' = 'A'
asciiFlatten 'Å' = 'A'
asciiFlatten 'à' = 'a'
asciiFlatten 'á' = 'a'
asciiFlatten 'â' = 'a'
asciiFlatten 'ã' = 'a'
asciiFlatten 'ä' = 'a'
asciiFlatten 'å' = 'a'
asciiFlatten 'Ā' = 'A'
asciiFlatten 'ā' = 'a'
asciiFlatten 'Ă' = 'A'
asciiFlatten 'ă' = 'a'
asciiFlatten '𐌀' = 'a'
asciiFlatten 'Ą' = 'A'
asciiFlatten 'ą' = 'a'
asciiFlatten 'Ǎ' = 'A'
asciiFlatten 'ǎ' = 'a'
asciiFlatten 'Ǟ' = 'A'
asciiFlatten 'ǟ' = 'a'
asciiFlatten 'Ǡ' = 'A'
asciiFlatten 'ǡ' = 'a'
asciiFlatten 'Ǻ' = 'A'
asciiFlatten 'ǻ' = 'a'
asciiFlatten 'Ȁ' = 'A'
asciiFlatten 'ȁ' = 'a'
asciiFlatten 'Ȃ' = 'A'
asciiFlatten 'ȃ' = 'a'
asciiFlatten 'Ȧ' = 'A'
asciiFlatten 'ȧ' = 'a'
asciiFlatten 'Ⱥ' = 'A'
asciiFlatten 'ɐ' = 'a'
asciiFlatten 'Ӑ' = 'A'
asciiFlatten 'ӑ' = 'a'
asciiFlatten 'ᴬ' = 'a'
asciiFlatten 'ᵃ' = 'a'
asciiFlatten 'ᵄ' = 'a'
asciiFlatten 'ᶏ' = 'a'
asciiFlatten 'Ḁ' = 'A'
asciiFlatten 'ḁ' = 'a'
asciiFlatten 'ẚ' = 'a'
asciiFlatten 'Ạ' = 'A'
asciiFlatten 'ạ' = 'a'
asciiFlatten 'Ả' = 'A'
asciiFlatten 'ả' = 'a'
asciiFlatten 'Ấ' = 'A'
asciiFlatten 'ấ' = 'a'
asciiFlatten 'Ầ' = 'A'
asciiFlatten 'ầ' = 'a'
asciiFlatten 'Ẩ' = 'A'
asciiFlatten 'ẩ' = 'a'
asciiFlatten 'Ẫ' = 'A'
asciiFlatten 'ẫ' = 'a'
asciiFlatten 'Ậ' = 'A'
asciiFlatten 'ậ' = 'a'
asciiFlatten 'Ắ' = 'A'
asciiFlatten 'ắ' = 'a'
asciiFlatten 'Ằ' = 'A'
asciiFlatten 'ằ' = 'a'
asciiFlatten 'Ẳ' = 'A'
asciiFlatten 'ẳ' = 'a'
asciiFlatten 'Ẵ' = 'A'
asciiFlatten 'ẵ' = 'a'
asciiFlatten 'Ặ' = 'A'
asciiFlatten 'ặ' = 'a'
asciiFlatten 'ₐ' = 'a'
asciiFlatten 'ⱥ' = 'a'
asciiFlatten 'ƀ' = 'b'
asciiFlatten 'Ɓ' = 'B'
asciiFlatten 'Ƃ' = 'B'
asciiFlatten 'ƃ' = 'b'
asciiFlatten 'Ƀ' = 'B'
asciiFlatten 'ɓ' = 'b'
asciiFlatten 'ʙ' = 'b'
asciiFlatten 'ᛒ' = 'b'
asciiFlatten 'ᴃ' = 'b'
asciiFlatten 'ᴮ' = 'b'
asciiFlatten 'ᴯ' = 'b'
asciiFlatten 'ᵇ' = 'b'
asciiFlatten 'ᵬ' = 'b'
asciiFlatten 'ᶀ' = 'b'
asciiFlatten 'Ḃ' = 'B'
asciiFlatten 'ḃ' = 'b'
asciiFlatten 'Ḅ' = 'B'
asciiFlatten 'ḅ' = 'b'
asciiFlatten 'Ḇ' = 'B'
asciiFlatten 'ḇ' = 'b'
asciiFlatten 'Ç' = 'C'
asciiFlatten 'ç' = 'c'
asciiFlatten 'Ć' = 'C'
asciiFlatten 'ć' = 'c'
asciiFlatten 'Ĉ' = 'C'
asciiFlatten 'ĉ' = 'c'
asciiFlatten 'Ċ' = 'C'
asciiFlatten 'ċ' = 'c'
asciiFlatten 'Č' = 'C'
asciiFlatten 'č' = 'c'
asciiFlatten 'Ƈ' = 'C'
asciiFlatten 'ƈ' = 'c'
asciiFlatten 'Ȼ' = 'C'
asciiFlatten 'ȼ' = 'c'
asciiFlatten 'ɕ' = 'c'
asciiFlatten 'ʗ' = 'c'
asciiFlatten 'ᶜ' = 'c'
asciiFlatten 'ᶝ' = 'c'
asciiFlatten 'Ḉ' = 'C'
asciiFlatten 'ḉ' = 'c'
asciiFlatten 'ℭ' = 'C'
asciiFlatten 'ↄ' = 'c'
asciiFlatten 'Ď' = 'D'
asciiFlatten 'ď' = 'd'
asciiFlatten 'Đ' = 'D'
asciiFlatten 'đ' = 'd'
asciiFlatten 'Ɖ' = 'D'
asciiFlatten 'Ɗ' = 'D'
asciiFlatten 'Ƌ' = 'D'
asciiFlatten 'ƌ' = 'd'
asciiFlatten 'ǅ' = 'D'
asciiFlatten 'ǲ' = 'D'
asciiFlatten 'ȡ' = 'd'
asciiFlatten 'ɖ' = 'd'
asciiFlatten 'ɗ' = 'd'
asciiFlatten 'ᴅ' = 'd'
asciiFlatten 'ᴰ' = 'd'
asciiFlatten 'ᵈ' = 'd'
asciiFlatten 'ᵭ' = 'd'
asciiFlatten 'ᶁ' = 'd'
asciiFlatten 'ᶑ' = 'd'
asciiFlatten 'Ḋ' = 'D'
asciiFlatten 'ḋ' = 'd'
asciiFlatten 'Ḍ' = 'D'
asciiFlatten 'ḍ' = 'd'
asciiFlatten 'Ḏ' = 'D'
asciiFlatten 'ḏ' = 'd'
asciiFlatten 'Ḑ' = 'D'
asciiFlatten 'ḑ' = 'd'
asciiFlatten 'Ḓ' = 'D'
asciiFlatten 'ḓ' = 'd'
asciiFlatten 'È' = 'E'
asciiFlatten 'É' = 'E'
asciiFlatten 'Ê' = 'E'
asciiFlatten 'Ë' = 'E'
asciiFlatten 'è' = 'e'
asciiFlatten 'é' = 'e'
asciiFlatten 'ê' = 'e'
asciiFlatten 'ë' = 'e'
asciiFlatten 'Ē' = 'E'
asciiFlatten 'ē' = 'e'
asciiFlatten 'Ĕ' = 'E'
asciiFlatten 'ĕ' = 'e'
asciiFlatten 'Ė' = 'E'
asciiFlatten 'ė' = 'e'
asciiFlatten 'Ę' = 'E'
asciiFlatten 'ę' = 'e'
asciiFlatten 'Ě' = 'E'
asciiFlatten 'ě' = 'e'
asciiFlatten 'Ǝ' = 'E'
asciiFlatten 'Ɛ' = 'E'
asciiFlatten 'ǝ' = 'e'
asciiFlatten 'Ȅ' = 'E'
asciiFlatten 'ȅ' = 'e'
asciiFlatten 'Ȇ' = 'E'
asciiFlatten 'ȇ' = 'e'
asciiFlatten 'Ȩ' = 'E'
asciiFlatten 'ȩ' = 'e'
asciiFlatten 'Ɇ' = 'E'
asciiFlatten 'ɇ' = 'e'
asciiFlatten 'ɘ' = 'e'
asciiFlatten 'ɛ' = 'e'
asciiFlatten 'ɜ' = 'e'
asciiFlatten 'ɝ' = 'e'
asciiFlatten 'ɞ' = 'e'
asciiFlatten 'ʚ' = 'e'
asciiFlatten 'ᴇ' = 'e'
asciiFlatten 'ᴈ' = 'e'
asciiFlatten 'ᴱ' = 'e'
asciiFlatten 'ᴲ' = 'e'
asciiFlatten 'ᵉ' = 'e'
asciiFlatten 'ᵋ' = 'e'
asciiFlatten 'ᵌ' = 'e'
asciiFlatten 'ᶒ' = 'e'
asciiFlatten 'ᶓ' = 'e'
asciiFlatten 'ᶔ' = 'e'
asciiFlatten 'ᶟ' = 'e'
asciiFlatten 'Ḕ' = 'E'
asciiFlatten 'ḕ' = 'e'
asciiFlatten 'Ḗ' = 'E'
asciiFlatten 'ḗ' = 'e'
asciiFlatten 'Ḙ' = 'E'
asciiFlatten 'ḙ' = 'e'
asciiFlatten 'Ḛ' = 'E'
asciiFlatten 'ḛ' = 'e'
asciiFlatten 'Ḝ' = 'E'
asciiFlatten 'ḝ' = 'e'
asciiFlatten 'Ẹ' = 'E'
asciiFlatten 'ẹ' = 'e'
asciiFlatten 'Ẻ' = 'E'
asciiFlatten 'ẻ' = 'e'
asciiFlatten 'Ẽ' = 'E'
asciiFlatten 'ẽ' = 'e'
asciiFlatten 'Ế' = 'E'
asciiFlatten 'ế' = 'e'
asciiFlatten 'Ề' = 'E'
asciiFlatten 'ề' = 'e'
asciiFlatten 'Ể' = 'E'
asciiFlatten 'ể' = 'e'
asciiFlatten 'Ễ' = 'E'
asciiFlatten 'ễ' = 'e'
asciiFlatten 'Ệ' = 'E'
asciiFlatten 'ệ' = 'e'
asciiFlatten 'ₑ' = 'e'
asciiFlatten 'Ƒ' = 'F'
asciiFlatten 'ƒ' = 'f'
asciiFlatten 'ᵮ' = 'f'
asciiFlatten 'ᶂ' = 'f'
asciiFlatten 'ᶠ' = 'f'
asciiFlatten 'Ḟ' = 'F'
asciiFlatten 'ḟ' = 'f'
asciiFlatten 'Ĝ' = 'G'
asciiFlatten 'ĝ' = 'g'
asciiFlatten 'Ğ' = 'G'
asciiFlatten 'ğ' = 'g'
asciiFlatten 'Ġ' = 'G'
asciiFlatten 'ġ' = 'g'
asciiFlatten 'Ģ' = 'G'
asciiFlatten 'ģ' = 'g'
asciiFlatten 'Ɠ' = 'G'
asciiFlatten 'Ǥ' = 'G'
asciiFlatten 'ǥ' = 'g'
asciiFlatten 'Ǧ' = 'G'
asciiFlatten 'ǧ' = 'g'
asciiFlatten 'Ǵ' = 'G'
asciiFlatten 'ǵ' = 'g'
asciiFlatten 'ɠ' = 'g'
asciiFlatten 'ɡ' = 'g'
asciiFlatten 'ɢ' = 'g'
asciiFlatten 'ʛ' = 'g'
asciiFlatten 'ᴳ' = 'g'
asciiFlatten 'ᵍ' = 'g'
asciiFlatten 'ᵷ' = 'g'
asciiFlatten 'ᵹ' = 'g'
asciiFlatten 'ᶃ' = 'g'
asciiFlatten 'ᶢ' = 'g'
asciiFlatten 'Ḡ' = 'G'
asciiFlatten 'ḡ' = 'g'
asciiFlatten 'Ĥ' = 'H'
asciiFlatten 'ĥ' = 'h'
asciiFlatten 'Ħ' = 'H'
asciiFlatten 'ħ' = 'h'
asciiFlatten 'Ȟ' = 'H'
asciiFlatten 'ȟ' = 'h'
asciiFlatten 'ɥ' = 'h'
asciiFlatten 'ɦ' = 'h'
asciiFlatten 'ʜ' = 'h'
asciiFlatten 'ʮ' = 'h'
asciiFlatten 'ʯ' = 'h'
asciiFlatten 'ʰ' = 'h'
asciiFlatten 'ʱ' = 'h'
asciiFlatten 'ᴴ' = 'h'
asciiFlatten 'ᶣ' = 'h'
asciiFlatten 'Ḣ' = 'H'
asciiFlatten 'ḣ' = 'h'
asciiFlatten 'Ḥ' = 'H'
asciiFlatten 'ḥ' = 'h'
asciiFlatten 'Ḧ' = 'H'
asciiFlatten 'ḧ' = 'h'
asciiFlatten 'Ḩ' = 'H'
asciiFlatten 'ḩ' = 'h'
asciiFlatten 'Ḫ' = 'H'
asciiFlatten 'ḫ' = 'h'
asciiFlatten 'ẖ' = 'h'
asciiFlatten 'ℌ' = 'H'
asciiFlatten 'Ⱨ' = 'H'
asciiFlatten 'ⱨ' = 'h'
asciiFlatten 'Ⱶ' = 'H'
asciiFlatten 'ⱶ' = 'h'
asciiFlatten 'Ì' = 'I'
asciiFlatten 'Í' = 'I'
asciiFlatten 'Î' = 'I'
asciiFlatten 'Ï' = 'I'
asciiFlatten 'ì' = 'i'
asciiFlatten 'í' = 'i'
asciiFlatten 'î' = 'i'
asciiFlatten 'ï' = 'i'
asciiFlatten '𐌉' = 'i'
asciiFlatten 'Ĩ' = 'I'
asciiFlatten 'ĩ' = 'i'
asciiFlatten 'Ī' = 'I'
asciiFlatten 'ī' = 'i'
asciiFlatten 'Ĭ' = 'I'
asciiFlatten 'ĭ' = 'i'
asciiFlatten 'Į' = 'I'
asciiFlatten 'į' = 'i'
asciiFlatten 'İ' = 'I'
asciiFlatten 'ı' = 'i'
asciiFlatten 'Ɨ' = 'I'
asciiFlatten 'Ǐ' = 'I'
asciiFlatten 'ǐ' = 'i'
asciiFlatten 'Ȉ' = 'I'
asciiFlatten 'ȉ' = 'i'
asciiFlatten 'Ȋ' = 'I'
asciiFlatten 'ȋ' = 'i'
asciiFlatten 'ɨ' = 'i'
asciiFlatten 'ɪ' = 'i'
asciiFlatten 'Ѝ' = 'I'
asciiFlatten 'И' = 'I'
asciiFlatten 'Й' = 'I'
asciiFlatten 'и' = 'i'
asciiFlatten 'й' = 'i'
asciiFlatten 'і' = 'i'
asciiFlatten 'ᴉ' = 'i'
asciiFlatten 'ᴵ' = 'i'
asciiFlatten 'ᵎ' = 'i'
asciiFlatten 'ᵢ' = 'i'
asciiFlatten 'ᵻ' = 'i'
asciiFlatten 'ᶖ' = 'i'
asciiFlatten 'ᶤ' = 'i'
asciiFlatten 'ᶦ' = 'i'
asciiFlatten 'ᶧ' = 'i'
asciiFlatten 'Ḭ' = 'I'
asciiFlatten 'ḭ' = 'i'
asciiFlatten 'Ḯ' = 'I'
asciiFlatten 'ḯ' = 'i'
asciiFlatten 'Ỉ' = 'I'
asciiFlatten 'ỉ' = 'i'
asciiFlatten 'Ị' = 'I'
asciiFlatten 'ị' = 'i'
asciiFlatten 'ⁱ' = 'i'
asciiFlatten 'ℑ' = 'I'
asciiFlatten 'Ĵ' = 'J'
asciiFlatten 'ĵ' = 'j'
asciiFlatten 'ǈ' = 'J'
asciiFlatten 'ǋ' = 'J'
asciiFlatten 'ǰ' = 'j'
asciiFlatten 'ȷ' = 'j'
asciiFlatten 'Ɉ' = 'J'
asciiFlatten 'ɉ' = 'j'
asciiFlatten 'ɟ' = 'j'
asciiFlatten 'ʄ' = 'j'
asciiFlatten 'ʝ' = 'j'
asciiFlatten 'ʲ' = 'j'
asciiFlatten 'ᴊ' = 'j'
asciiFlatten 'ᴶ' = 'j'
asciiFlatten 'ᶡ' = 'j'
asciiFlatten 'ᶨ' = 'j'
asciiFlatten 'Ķ' = 'K'
asciiFlatten 'ķ' = 'k'
asciiFlatten 'Ƙ' = 'K'
asciiFlatten 'ƙ' = 'k'
asciiFlatten 'Ǩ' = 'K'
asciiFlatten 'ǩ' = 'k'
asciiFlatten 'ʞ' = 'k'
asciiFlatten 'ᴋ' = 'k'
asciiFlatten 'ᴷ' = 'k'
asciiFlatten 'ᵏ' = 'k'
asciiFlatten 'ᶄ' = 'k'
asciiFlatten 'Ḱ' = 'K'
asciiFlatten 'ḱ' = 'k'
asciiFlatten 'Ḳ' = 'K'
asciiFlatten 'ḳ' = 'k'
asciiFlatten 'Ḵ' = 'K'
asciiFlatten 'ḵ' = 'k'
asciiFlatten 'Ⱪ' = 'K'
asciiFlatten 'ⱪ' = 'k'
asciiFlatten 'Ĺ' = 'L'
asciiFlatten 'ĺ' = 'l'
asciiFlatten 'Ļ' = 'L'
asciiFlatten 'ļ' = 'l'
asciiFlatten 'Ľ' = 'L'
asciiFlatten 'ľ' = 'l'
asciiFlatten 'Ŀ' = 'L'
asciiFlatten 'ŀ' = 'l'
asciiFlatten 'Ł' = 'L'
asciiFlatten 'ł' = 'l'
asciiFlatten 'ƚ' = 'l'
asciiFlatten 'ǈ' = 'L'
asciiFlatten 'ȴ' = 'l'
asciiFlatten 'Ƚ' = 'L'
asciiFlatten 'ɫ' = 'l'
asciiFlatten 'ɬ' = 'l'
asciiFlatten 'ɭ' = 'l'
asciiFlatten 'ʟ' = 'l'
asciiFlatten 'ˡ' = 'l'
asciiFlatten 'ᴌ' = 'l'
asciiFlatten 'ᴸ' = 'l'
asciiFlatten 'ᶅ' = 'l'
asciiFlatten 'ᶩ' = 'l'
asciiFlatten 'ᶪ' = 'l'
asciiFlatten 'ᶫ' = 'l'
asciiFlatten 'Ḷ' = 'L'
asciiFlatten 'ḷ' = 'l'
asciiFlatten 'Ḹ' = 'L'
asciiFlatten 'ḹ' = 'l'
asciiFlatten 'Ḻ' = 'L'
asciiFlatten 'ḻ' = 'l'
asciiFlatten 'Ḽ' = 'L'
asciiFlatten 'ḽ' = 'l'
asciiFlatten 'Ⱡ' = 'L'
asciiFlatten 'ⱡ' = 'l'
asciiFlatten 'Ɫ' = 'L'
asciiFlatten 'Ɯ' = 'M'
asciiFlatten 'ɯ' = 'm'
asciiFlatten 'ɰ' = 'm'
asciiFlatten 'ɱ' = 'm'
asciiFlatten 'ᴍ' = 'm'
asciiFlatten 'ᴟ' = 'm'
asciiFlatten 'ᴹ' = 'm'
asciiFlatten 'ᵐ' = 'm'
asciiFlatten 'ᵚ' = 'm'
asciiFlatten 'ᵯ' = 'm'
asciiFlatten 'ᶆ' = 'm'
asciiFlatten 'ᶬ' = 'm'
asciiFlatten 'ᶭ' = 'm'
asciiFlatten 'Ḿ' = 'M'
asciiFlatten 'ḿ' = 'm'
asciiFlatten 'Ṁ' = 'M'
asciiFlatten 'ṁ' = 'm'
asciiFlatten 'Ṃ' = 'M'
asciiFlatten 'ṃ' = 'm'
asciiFlatten 'Ñ' = 'N'
asciiFlatten 'ñ' = 'n'
asciiFlatten 'Ń' = 'N'
asciiFlatten 'ń' = 'n'
asciiFlatten 'Ņ' = 'N'
asciiFlatten 'ņ' = 'n'
asciiFlatten 'Ň' = 'N'
asciiFlatten 'ň' = 'n'
asciiFlatten 'ŉ' = 'n'
asciiFlatten 'Ɲ' = 'N'
asciiFlatten 'ƞ' = 'n'
asciiFlatten 'ǋ' = 'N'
asciiFlatten 'Ǹ' = 'N'
asciiFlatten 'ǹ' = 'n'
asciiFlatten 'Ƞ' = 'N'
asciiFlatten 'ȵ' = 'n'
asciiFlatten 'ɲ' = 'n'
asciiFlatten 'ɳ' = 'n'
asciiFlatten 'ɴ' = 'n'
asciiFlatten 'ᴎ' = 'n'
asciiFlatten 'ᴺ' = 'n'
asciiFlatten 'ᴻ' = 'n'
asciiFlatten 'ᵰ' = 'n'
asciiFlatten 'ᶇ' = 'n'
asciiFlatten 'ᶮ' = 'n'
asciiFlatten 'ᶯ' = 'n'
asciiFlatten 'ᶰ' = 'n'
asciiFlatten 'Ṅ' = 'N'
asciiFlatten 'ṅ' = 'n'
asciiFlatten 'Ṇ' = 'N'
asciiFlatten 'ṇ' = 'n'
asciiFlatten 'Ṉ' = 'N'
asciiFlatten 'ṉ' = 'n'
asciiFlatten 'Ṋ' = 'N'
asciiFlatten 'ṋ' = 'n'
asciiFlatten 'ⁿ' = 'n'
asciiFlatten 'Ò' = 'O'
asciiFlatten 'Ó' = 'O'
asciiFlatten 'Ô' = 'O'
asciiFlatten 'Õ' = 'O'
asciiFlatten 'Ö' = 'O'
asciiFlatten 'Ø' = 'O'
asciiFlatten 'ò' = 'o'
asciiFlatten 'ó' = 'o'
asciiFlatten 'ô' = 'o'
asciiFlatten 'õ' = 'o'
asciiFlatten 'ö' = 'o'
asciiFlatten 'ø' = 'o'
asciiFlatten '𐌏' = 'o'
asciiFlatten 'Ō' = 'O'
asciiFlatten 'ō' = 'o'
asciiFlatten 'Ŏ' = 'O'
asciiFlatten 'ŏ' = 'o'
asciiFlatten 'Ő' = 'O'
asciiFlatten 'ő' = 'o'
asciiFlatten 'Ɔ' = 'O'
asciiFlatten 'Ɵ' = 'O'
asciiFlatten 'Ơ' = 'O'
asciiFlatten 'ơ' = 'o'
asciiFlatten 'Ǒ' = 'O'
asciiFlatten 'ǒ' = 'o'
asciiFlatten 'Ǫ' = 'O'
asciiFlatten 'ǫ' = 'o'
asciiFlatten 'Ǭ' = 'O'
asciiFlatten 'ǭ' = 'o'
asciiFlatten 'Ǿ' = 'O'
asciiFlatten 'ǿ' = 'o'
asciiFlatten 'Ȍ' = 'O'
asciiFlatten 'ȍ' = 'o'
asciiFlatten 'Ȏ' = 'O'
asciiFlatten 'ȏ' = 'o'
asciiFlatten 'Ȫ' = 'O'
asciiFlatten 'ȫ' = 'o'
asciiFlatten 'Ȭ' = 'O'
asciiFlatten 'ȭ' = 'o'
asciiFlatten 'Ȯ' = 'O'
asciiFlatten 'ȯ' = 'o'
asciiFlatten 'Ȱ' = 'O'
asciiFlatten 'ȱ' = 'o'
asciiFlatten 'ɔ' = 'o'
asciiFlatten 'ɵ' = 'o'
asciiFlatten 'о' = 'o'
asciiFlatten 'Ӧ' = 'O'
asciiFlatten 'ӧ' = 'o'
asciiFlatten 'Ө' = 'O'
asciiFlatten 'ө' = 'o'
asciiFlatten 'Ӫ' = 'O'
asciiFlatten 'ӫ' = 'o'
asciiFlatten 'ᴏ' = 'o'
asciiFlatten 'ᴐ' = 'o'
asciiFlatten 'ᴑ' = 'o'
asciiFlatten 'ᴒ' = 'o'
asciiFlatten 'ᴓ' = 'o'
asciiFlatten 'ᴖ' = 'o'
asciiFlatten 'ᴗ' = 'o'
asciiFlatten 'ᴼ' = 'o'
asciiFlatten 'ᵒ' = 'o'
asciiFlatten 'ᵓ' = 'o'
asciiFlatten 'ᵔ' = 'o'
asciiFlatten 'ᵕ' = 'o'
asciiFlatten 'ᶗ' = 'o'
asciiFlatten 'ᶱ' = 'o'
asciiFlatten 'Ṍ' = 'O'
asciiFlatten 'ṍ' = 'o'
asciiFlatten 'Ṏ' = 'O'
asciiFlatten 'ṏ' = 'o'
asciiFlatten 'Ṑ' = 'O'
asciiFlatten 'ṑ' = 'o'
asciiFlatten 'Ṓ' = 'O'
asciiFlatten 'ṓ' = 'o'
asciiFlatten 'Ọ' = 'O'
asciiFlatten 'ọ' = 'o'
asciiFlatten 'Ỏ' = 'O'
asciiFlatten 'ỏ' = 'o'
asciiFlatten 'Ố' = 'O'
asciiFlatten 'ố' = 'o'
asciiFlatten 'Ồ' = 'O'
asciiFlatten 'ồ' = 'o'
asciiFlatten 'Ổ' = 'O'
asciiFlatten 'ổ' = 'o'
asciiFlatten 'Ỗ' = 'O'
asciiFlatten 'ỗ' = 'o'
asciiFlatten 'Ộ' = 'O'
asciiFlatten 'ộ' = 'o'
asciiFlatten 'Ớ' = 'O'
asciiFlatten 'ớ' = 'o'
asciiFlatten 'Ờ' = 'O'
asciiFlatten 'ờ' = 'o'
asciiFlatten 'Ở' = 'O'
asciiFlatten 'ở' = 'o'
asciiFlatten 'Ỡ' = 'O'
asciiFlatten 'ỡ' = 'o'
asciiFlatten 'Ợ' = 'O'
asciiFlatten 'ợ' = 'o'
asciiFlatten 'ₒ' = 'o'
asciiFlatten 'Ⲟ' = 'O'
asciiFlatten 'ⲟ' = 'o'
asciiFlatten 'Ƥ' = 'P'
asciiFlatten 'ƥ' = 'p'
asciiFlatten 'ᴘ' = 'p'
asciiFlatten 'ᴾ' = 'p'
asciiFlatten 'ᵖ' = 'p'
asciiFlatten 'ᵱ' = 'p'
asciiFlatten 'ᵽ' = 'p'
asciiFlatten 'ᶈ' = 'p'
asciiFlatten 'Ṕ' = 'P'
asciiFlatten 'ṕ' = 'p'
asciiFlatten 'Ṗ' = 'P'
asciiFlatten 'ṗ' = 'p'
asciiFlatten 'Ᵽ' = 'P'
asciiFlatten 'Ɋ' = 'Q'
asciiFlatten 'ɋ' = 'q'
asciiFlatten 'ʠ' = 'q'
asciiFlatten 'Ŕ' = 'R'
asciiFlatten 'ŕ' = 'r'
asciiFlatten 'Ŗ' = 'R'
asciiFlatten 'ŗ' = 'r'
asciiFlatten 'Ř' = 'R'
asciiFlatten 'ř' = 'r'
asciiFlatten 'Ȑ' = 'R'
asciiFlatten 'ȑ' = 'r'
asciiFlatten 'Ȓ' = 'R'
asciiFlatten 'ȓ' = 'r'
asciiFlatten 'Ɍ' = 'R'
asciiFlatten 'ɍ' = 'r'
asciiFlatten 'ɹ' = 'r'
asciiFlatten 'ɺ' = 'r'
asciiFlatten 'ɻ' = 'r'
asciiFlatten 'ɼ' = 'r'
asciiFlatten 'ɽ' = 'r'
asciiFlatten 'ɾ' = 'r'
asciiFlatten 'ɿ' = 'r'
asciiFlatten 'ʀ' = 'r'
asciiFlatten 'ʁ' = 'r'
asciiFlatten 'ʳ' = 'r'
asciiFlatten 'ʴ' = 'r'
asciiFlatten 'ʵ' = 'r'
asciiFlatten 'ʶ' = 'r'
asciiFlatten 'ᴙ' = 'r'
asciiFlatten 'ᴚ' = 'r'
asciiFlatten 'ᴿ' = 'r'
asciiFlatten 'ᵣ' = 'r'
asciiFlatten 'ᵲ' = 'r'
asciiFlatten 'ᵳ' = 'r'
asciiFlatten 'ᶉ' = 'r'
asciiFlatten '᷊' = 'r'
asciiFlatten 'Ṙ' = 'R'
asciiFlatten 'ṙ' = 'r'
asciiFlatten 'Ṛ' = 'R'
asciiFlatten 'ṛ' = 'r'
asciiFlatten 'Ṝ' = 'R'
asciiFlatten 'ṝ' = 'r'
asciiFlatten 'Ṟ' = 'R'
asciiFlatten 'ṟ' = 'r'
asciiFlatten 'ℜ' = 'R'
asciiFlatten 'Ɽ' = 'R'
asciiFlatten 'ß' = 's'
asciiFlatten 'Ś' = 'S'
asciiFlatten 'ś' = 's'
asciiFlatten 'Ŝ' = 'S'
asciiFlatten 'ŝ' = 's'
asciiFlatten 'Ş' = 'S'
asciiFlatten 'ş' = 's'
asciiFlatten 'Š' = 'S'
asciiFlatten 'š' = 's'
asciiFlatten 'ſ' = 's'
asciiFlatten 'Ș' = 'S'
asciiFlatten 'ș' = 's'
asciiFlatten 'ȿ' = 's'
asciiFlatten 'ʂ' = 's'
asciiFlatten 'ˢ' = 's'
asciiFlatten 'ᵴ' = 's'
asciiFlatten 'ᶊ' = 's'
asciiFlatten 'ᶳ' = 's'
asciiFlatten 'Ṡ' = 'S'
asciiFlatten 'ṡ' = 's'
asciiFlatten 'Ṣ' = 'S'
asciiFlatten 'ṣ' = 's'
asciiFlatten 'Ṥ' = 'S'
asciiFlatten 'ṥ' = 's'
asciiFlatten 'Ṧ' = 'S'
asciiFlatten 'ṧ' = 's'
asciiFlatten 'Ṩ' = 'S'
asciiFlatten 'ṩ' = 's'
asciiFlatten 'ẛ' = 's'
asciiFlatten 'Ţ' = 'T'
asciiFlatten 'ţ' = 't'
asciiFlatten 'Ť' = 'T'
asciiFlatten 'ť' = 't'
asciiFlatten 'Ŧ' = 'T'
asciiFlatten 'ŧ' = 't'
asciiFlatten 'ƫ' = 't'
asciiFlatten 'Ƭ' = 'T'
asciiFlatten 'ƭ' = 't'
asciiFlatten 'Ʈ' = 'T'
asciiFlatten 'Ț' = 'T'
asciiFlatten 'ț' = 't'
asciiFlatten 'ȶ' = 't'
asciiFlatten 'Ⱦ' = 'T'
asciiFlatten 'ʇ' = 't'
asciiFlatten 'ʈ' = 't'
asciiFlatten 'ᴛ' = 't'
asciiFlatten 'ᵀ' = 't'
asciiFlatten 'ᵗ' = 't'
asciiFlatten 'ᵵ' = 't'
asciiFlatten 'ᶵ' = 't'
asciiFlatten 'Ṫ' = 'T'
asciiFlatten 'ṫ' = 't'
asciiFlatten 'Ṭ' = 'T'
asciiFlatten 'ṭ' = 't'
asciiFlatten 'Ṯ' = 'T'
asciiFlatten 'ṯ' = 't'
asciiFlatten 'Ṱ' = 'T'
asciiFlatten 'ṱ' = 't'
asciiFlatten 'ẗ' = 't'
asciiFlatten 'ⱦ' = 't'
asciiFlatten 'Ù' = 'U'
asciiFlatten 'Ú' = 'U'
asciiFlatten 'Û' = 'U'
asciiFlatten 'Ü' = 'U'
asciiFlatten 'ù' = 'u'
asciiFlatten 'ú' = 'u'
asciiFlatten 'û' = 'u'
asciiFlatten 'ü' = 'u'
asciiFlatten '𐌖' = 'u'
asciiFlatten 'Ũ' = 'U'
asciiFlatten 'ũ' = 'u'
asciiFlatten 'Ū' = 'U'
asciiFlatten 'ū' = 'u'
asciiFlatten 'Ŭ' = 'U'
asciiFlatten 'ŭ' = 'u'
asciiFlatten 'Ů' = 'U'
asciiFlatten 'ů' = 'u'
asciiFlatten 'Ű' = 'U'
asciiFlatten 'ű' = 'u'
asciiFlatten 'Ų' = 'U'
asciiFlatten 'ų' = 'u'
asciiFlatten 'Ư' = 'U'
asciiFlatten 'ư' = 'u'
asciiFlatten 'Ǔ' = 'U'
asciiFlatten 'ǔ' = 'u'
asciiFlatten 'Ǖ' = 'U'
asciiFlatten 'ǖ' = 'u'
asciiFlatten 'Ǘ' = 'U'
asciiFlatten 'ǘ' = 'u'
asciiFlatten 'Ǚ' = 'U'
asciiFlatten 'ǚ' = 'u'
asciiFlatten 'Ǜ' = 'U'
asciiFlatten 'ǜ' = 'u'
asciiFlatten 'Ȕ' = 'U'
asciiFlatten 'ȕ' = 'u'
asciiFlatten 'Ȗ' = 'U'
asciiFlatten 'ȗ' = 'u'
asciiFlatten 'Ʉ' = 'U'
asciiFlatten 'ʉ' = 'u'
asciiFlatten 'ᴜ' = 'u'
asciiFlatten 'ᴝ' = 'u'
asciiFlatten 'ᴞ' = 'u'
asciiFlatten 'ᵁ' = 'u'
asciiFlatten 'ᵘ' = 'u'
asciiFlatten 'ᵙ' = 'u'
asciiFlatten 'ᵤ' = 'u'
asciiFlatten 'ᵾ' = 'u'
asciiFlatten 'ᶙ' = 'u'
asciiFlatten 'ᶶ' = 'u'
asciiFlatten 'ᶸ' = 'u'
asciiFlatten 'Ṳ' = 'U'
asciiFlatten 'ṳ' = 'u'
asciiFlatten 'Ṵ' = 'U'
asciiFlatten 'ṵ' = 'u'
asciiFlatten 'Ṷ' = 'U'
asciiFlatten 'ṷ' = 'u'
asciiFlatten 'Ṹ' = 'U'
asciiFlatten 'ṹ' = 'u'
asciiFlatten 'Ṻ' = 'U'
asciiFlatten 'ṻ' = 'u'
asciiFlatten 'Ụ' = 'U'
asciiFlatten 'ụ' = 'u'
asciiFlatten 'Ủ' = 'U'
asciiFlatten 'ủ' = 'u'
asciiFlatten 'Ứ' = 'U'
asciiFlatten 'ứ' = 'u'
asciiFlatten 'Ừ' = 'U'
asciiFlatten 'ừ' = 'u'
asciiFlatten 'Ử' = 'U'
asciiFlatten 'ử' = 'u'
asciiFlatten 'Ữ' = 'U'
asciiFlatten 'ữ' = 'u'
asciiFlatten 'Ự' = 'U'
asciiFlatten 'ự' = 'u'
asciiFlatten 'Ʋ' = 'V'
asciiFlatten 'Ʌ' = 'V'
asciiFlatten 'ʋ' = 'v'
asciiFlatten 'ʌ' = 'v'
asciiFlatten 'ᴠ' = 'v'
asciiFlatten 'ᵛ' = 'v'
asciiFlatten 'ᵥ' = 'v'
asciiFlatten 'ᶌ' = 'v'
asciiFlatten 'ᶹ' = 'v'
asciiFlatten 'ᶺ' = 'v'
asciiFlatten 'Ṽ' = 'V'
asciiFlatten 'ṽ' = 'v'
asciiFlatten 'Ṿ' = 'V'
asciiFlatten 'ṿ' = 'v'
asciiFlatten 'ⱴ' = 'v'
asciiFlatten 'Ŵ' = 'W'
asciiFlatten 'ŵ' = 'w'
asciiFlatten 'ʍ' = 'w'
asciiFlatten 'ʷ' = 'w'
asciiFlatten 'ᴡ' = 'w'
asciiFlatten 'ᵂ' = 'w'
asciiFlatten 'Ẁ' = 'W'
asciiFlatten 'ẁ' = 'w'
asciiFlatten 'Ẃ' = 'W'
asciiFlatten 'ẃ' = 'w'
asciiFlatten 'Ẅ' = 'W'
asciiFlatten 'ẅ' = 'w'
asciiFlatten 'Ẇ' = 'W'
asciiFlatten 'ẇ' = 'w'
asciiFlatten 'Ẉ' = 'W'
asciiFlatten 'ẉ' = 'w'
asciiFlatten 'ẘ' = 'w'
asciiFlatten 'ˣ' = 'x'
asciiFlatten 'ᶍ' = 'x'
asciiFlatten 'Ẋ' = 'X'
asciiFlatten 'ẋ' = 'x'
asciiFlatten 'Ẍ' = 'X'
asciiFlatten 'ẍ' = 'x'
asciiFlatten 'ₓ' = 'x'
asciiFlatten 'Ý' = 'Y'
asciiFlatten 'ý' = 'y'
asciiFlatten 'ÿ' = 'y'
asciiFlatten 'Ŷ' = 'Y'
asciiFlatten 'ŷ' = 'y'
asciiFlatten 'Ÿ' = 'Y'
asciiFlatten 'Ƴ' = 'Y'
asciiFlatten 'ƴ' = 'y'
asciiFlatten 'Ȳ' = 'Y'
asciiFlatten 'ȳ' = 'y'
asciiFlatten 'Ɏ' = 'Y'
asciiFlatten 'ɏ' = 'y'
asciiFlatten 'ʎ' = 'y'
asciiFlatten 'ʏ' = 'y'
asciiFlatten 'ʸ' = 'y'
asciiFlatten 'Ẏ' = 'Y'
asciiFlatten 'ẏ' = 'y'
asciiFlatten 'ẙ' = 'y'
asciiFlatten 'Ỳ' = 'Y'
asciiFlatten 'ỳ' = 'y'
asciiFlatten 'Ỵ' = 'Y'
asciiFlatten 'ỵ' = 'y'
asciiFlatten 'Ỷ' = 'Y'
asciiFlatten 'ỷ' = 'y'
asciiFlatten 'Ỹ' = 'Y'
asciiFlatten 'ỹ' = 'y'
asciiFlatten 'Ź' = 'Z'
asciiFlatten 'ź' = 'z'
asciiFlatten 'Ż' = 'Z'
asciiFlatten 'ż' = 'z'
asciiFlatten 'Ž' = 'Z'
asciiFlatten 'ž' = 'z'
asciiFlatten 'Ƶ' = 'Z'
asciiFlatten 'ƶ' = 'z'
asciiFlatten 'Ȥ' = 'Z'
asciiFlatten 'ȥ' = 'z'
asciiFlatten 'ɀ' = 'z'
asciiFlatten 'ʐ' = 'z'
asciiFlatten 'ʑ' = 'z'
asciiFlatten 'ᴢ' = 'z'
asciiFlatten 'ᵶ' = 'z'
asciiFlatten 'ᶎ' = 'z'
asciiFlatten 'ᶻ' = 'z'
asciiFlatten 'ᶼ' = 'z'
asciiFlatten 'ᶽ' = 'z'
asciiFlatten 'Ẑ' = 'Z'
asciiFlatten 'ẑ' = 'z'
asciiFlatten 'Ẓ' = 'Z'
asciiFlatten 'ẓ' = 'z'
asciiFlatten 'Ẕ' = 'Z'
asciiFlatten 'ẕ' = 'z'
asciiFlatten 'ℨ' = 'Z'
asciiFlatten 'Ⱬ' = 'Z'
asciiFlatten 'ⱬ' = 'z'
asciiFlatten x = x
